@@ -34,9 +34,14 @@
 #include "gtkhex.h"
 
 #define NO_BUFFER_LABEL "No buffer"
+
 #define DEFAULT_FONT    "-adobe-courier-medium-r-normal--12-*-*-*-*-*-*-*"
+
 #define MAX_MAX_UNDO_DEPTH 100000
 
+#define OFFSET_BASE_16 16
+#define OFFSET_BASE_10 10
+
 extern GnomeUIInfo help_menu[], file_menu[], view_menu[], main_menu[];
 
 #define DATA_TYPE_HEX   0
@@ -53,6 +58,8 @@ typedef struct _PropertyUI {
 	GtkRadioButton *mdi_type[NUM_MDI_MODES];
 	GtkRadioButton *group_type[3];
 	GtkWidget *font_button, *spin;
+	GtkWidget *offset_menu, *offset_choice[3];
+	GtkWidget *format, *offsets_col;
 } PropertyUI;
 
 typedef struct _JumpDialog {
@@ -83,7 +90,8 @@ typedef struct _Converter {
 	GtkWidget *window;
 	GtkWidget *entry[4];
 	GtkWidget *close;
-	
+	GtkWidget *get;
+
 	gulong value;
 } Converter;
 
@@ -108,6 +116,8 @@ extern GdkFont *def_font;
 extern gchar *def_font_name;
 
 extern guint max_undo_depth;
+extern gchar *offset_fmt;
+extern gboolean show_offsets_column;
 
 extern gint def_group_type;
 extern guint group_type[3];
