@@ -477,6 +477,7 @@ gint hex_document_write(HexDocument *doc) {
 		fwrite(doc->buffer, 1, doc->buffer_size, doc->file);
 		fclose(doc->file);
 		doc->file = 0;
+		doc->changed = FALSE;
 		undo_stack_free(doc);
 		return 0;
 	}
@@ -565,13 +566,17 @@ gint find_string_backward(HexDocument *doc, guint start, guchar *what, gint len,
 	guint pos;
 	
 	pos = start;
-	while(pos >= 0) {
+
+	if(pos == 0)
+		return 1;
+
+	do {
+		pos--;
 		if(compare_data(&doc->buffer[pos], what, len) == 0) {
 			*found = pos;
 			return 0;
 		}
-		pos--;
-	}
+	} while(pos > 0);
 	
 	return 1;
 }
